==> DeeType-0.1.tar.gz: DeeType-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'DeeType',         # How you named your package folder (MyLib)
  packages = ['DeeType'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A python package to classify data types from a list.',   # Give a short description about your library
  author = 'Hardeep SIngh',                   # Type in your name
  author_email = 'hardeep0khalsa122@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Hardeepsingh980/DeeType.git',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Hardeepsingh980/DeeType/archive/master.zip',    # I explain this later on
  keywords = ['Datatypes', 'classify', 'sort', 'datatypes'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second

      ],
  classifiers=[
    'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> DeeType-0.2.tar.gz: DeeType-0.2/setup.py <==
from distutils.core import setup
setup(
  name = 'DeeType',         # How you named your package folder (MyLib)
  packages = ['DeeType'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A python package to classify data types from a list.',   # Give a short description about your library
  author = 'Hardeep SIngh',                   # Type in your name
  author_email = 'hardeep0khalsa122@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Hardeepsingh980/DeeType.git',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Hardeepsingh980/DeeType/archive/master.zip',    # I explain this later on
  keywords = ['Datatypes', 'classify', 'sort', 'datatypes', 'int', 'string', 'dict', 'list'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second

      ],
  classifiers=[
    'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
